"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _isNumber2 = _interopRequireDefault(require("lodash/isNumber"));

var _isEmpty2 = _interopRequireDefault(require("lodash/isEmpty"));

var _sqlstring = _interopRequireDefault(require("sqlstring"));

class Statement {
  constructor(options = {}, entity) {
    this.options = options;
    this.entity = entity;
  }

  generate() {
    return "";
  }

  getColumns(options) {
    const columns = options.columns || [];

    if ((0, _isEmpty2.default)(columns)) {
      return " *";
    }

    return " " + columns.join(", ");
  }

  getWhere(options) {
    if ((0, _isEmpty2.default)(options.where)) {
      return "";
    }

    return " WHERE " + this.process({
      $and: options.where
    });
  }

  getGroup(options) {
    if (!(Array.isArray(options.groupBy) && options.groupBy.length > 0)) {
      return "";
    }

    return " GROUP BY " + options.groupBy.join(", ");
  }

  getOrder(options) {
    if (!(options.sort instanceof Object) || (0, _isEmpty2.default)(options.sort)) {
      return "";
    }

    let query = [];

    for (let key in options.sort) {
      query.push(`${key} ${options.sort[key] === 1 ? "ASC" : "DESC"}`);
    }

    return " ORDER BY " + query.join(", ");
  }

  getLimit(options) {
    const limit = options.limit || 0;

    if ((0, _isNumber2.default)(limit) && limit > 0) {
      return ` LIMIT ${limit}`;
    }

    return "";
  }

  getOffset(options) {
    const offset = options.offset || 0;

    if ((0, _isNumber2.default)(offset) && offset > 0) {
      return ` OFFSET ${offset}`;
    }

    return "";
  }

  escape(value) {
    return _sqlstring.default.escape(value);
  }
  /**
   * Traverse the payload and apply operators to construct a valid MySQL statement
   * @private
   * @param {Object} payload
   * @returns {string} SQL query
   */


  process(payload) {
    let output = "";

    outerLoop: for (const [key, value] of Object.entries(payload)) {
      const operators = Object.values(this.options.operators);

      for (let i = 0; i < operators.length; i++) {
        const operator = operators[i];

        if (operator.canProcess({
          key,
          value,
          statement: this
        })) {
          output += operator.process({
            key,
            value,
            statement: this
          });
          continue outerLoop;
        }
      }

      throw new Error(`Invalid operator {${key} : ${value}}.`);
    }

    return output;
  }

}

var _default = Statement;
exports.default = _default;
//# sourceMappingURL=statement.js.map